/*$Id: d_dot.cc,v 17.23 2000/05/26 08:01:37 al Exp $ -*- C++ -*-
 * processing for DOTCARD netlist item (pseudo-device)
 * "parsing" a "dotcard" will execute it.
 * What actually happens (usually either to preset or really do)
 * depends on the option "run_mode", which depends on what command is running.
 */
#include "c_comand.h"
#include "ap.h"
#include "d_dot.h"
/*--------------------------------------------------------------------------*/
//	void	DEV_DOT::parse(CS& cmd);
//	void	DEV_DOT::print(int,int)const;
/*--------------------------------------------------------------------------*/
void DEV_DOT::parse(CS& cmd)
{
  cmd.reset();
  _s = cmd.fullstring();
  switch (ENV::run_mode){
  case rIGNORE:
    unreachable();
    /*nothing*/
    break;
  case rPRESET:
  case rINTERACTIVE:
  case rSCRIPT:
  case rBATCH:
    cmd.skip1b(".");
    CMD::cmdproc(cmd.tail());
    break;
  }
}
/*--------------------------------------------------------------------------*/
void DEV_DOT::print(OMSTREAM& where, int)const
{
  where << _s << '\n';
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
